@@ -12,7 +12,7 @@ writeListArraySDML <- function(x,
 {
   if (is.null(x))
     catSDML("\<empty/>\n", file = file)
-  else if (is.recursive(x) && !is.call(x) && !is.environment(x)) {	
+  else if (is.list(x)) {	
     catSDML("\<list>\n", file = file)
     writeDimensionSDML(x, file = file)
     writePropertiesSDML(attributes(x), file = file, textdata = textdata,
@@ -30,8 +30,6 @@ writeListArraySDML <- function(x,
   } else {
     catSDML("\<array>\n", file = file)
 
-    if (is.recursive(x)) x <- deparse(x)
-
     ## dimension tag
     writeDimensionSDML(x, file = file)
 
@@ -89,7 +87,7 @@ writeListArraySDML <- function(x,
     
     x <- switch (type,
                  logical = if (textdata) ifelse(x, true, false) else x,
-                 categorical = codes(x),
+                 categorical = as.numeric(x),
                  numeric = x,
                  datetime = as.character(x, format="%Y-%m-%dT%H:%M:%S"),
                  character = gsub("<", "&lt;", gsub(">", "&gt;", gsub("&", "&amp;", x)))
